@@ -101,10 +101,6 @@ eel_mime_application_chooser_finalize (GObject *object)
 static void
 eel_mime_application_chooser_destroy (GtkObject *object)
 {
-	EelMimeApplicationChooser *chooser;
-
-	chooser = EEL_MIME_APPLICATION_CHOOSER (object);
-	
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
@@ -323,6 +319,8 @@ eel_mime_application_chooser_instance_init (EelMimeApplicationChooser *chooser)
 	chooser->details->label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (chooser->details->label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (chooser->details->label), TRUE);
+	gtk_label_set_line_wrap_mode (GTK_LABEL (chooser->details->label),
+				      PANGO_WRAP_WORD_CHAR);
 	gtk_box_pack_start (GTK_BOX (chooser), chooser->details->label, 
 			    FALSE, FALSE, 0);
 
@@ -477,10 +475,12 @@ refresh_model (EelMimeApplicationChooser *chooser)
 
 		gtk_tree_view_column_set_visible (column, FALSE);
 		gtk_list_store_append (chooser->details->model, &iter);
+		gchar *name = g_strdup_printf ("<i>%s</i>", _("No applications selected"));
 		gtk_list_store_set (chooser->details->model, &iter,
-				    COLUMN_NAME, _("<i>No applications selected</i>"),
+				    COLUMN_NAME, name,
 				    COLUMN_ID, NULL,
 				    -1);
+		g_free (name);
 
 		gtk_tree_selection_set_mode (selection, GTK_SELECTION_NONE);
 	}
@@ -540,7 +540,9 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 	}
 
 	/* first %s is filename, second %s is mime-type description */
-	label = g_strdup_printf (_("Select an application to open <i>%s</i> and others of type \"%s\""), name, chooser->details->mime_description);
+	gchar *emname = g_strdup_printf ("<i>%s</i>", name);
+	label = g_strdup_printf (_("Select an application to open %s and others of type \"%s\""), emname, chooser->details->mime_description);
+	g_free (emname);
 	
 	gtk_label_set_markup (GTK_LABEL (chooser->details->label), label);
 
