@@ -508,8 +508,23 @@ static int
 compare_applications (GMenuTreeEntry *a,
 		      GMenuTreeEntry *b)
 {
-	return g_utf8_collate (gmenu_tree_entry_get_name (a),
-			       gmenu_tree_entry_get_name (b));
+	const char *name_a = gmenu_tree_entry_get_name (a);
+	const char *name_b = gmenu_tree_entry_get_name (b);
+
+	if (name_a == NULL && name_b == NULL) {
+		return 0;
+	}
+
+	if (name_a == NULL) {
+		return -1;
+	}
+
+	if (name_b == NULL) {
+		return 1;
+	}
+
+	return g_utf8_collate (name_a,
+			       name_b);
 }
 
 static GSList *
@@ -594,7 +609,8 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 		GtkTreeIter     iter;
 		GtkTreePath    *path;
 
-		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
+		const char *name = gmenu_tree_entry_get_name (entry);
+		if (!name || (prev_name && strcmp (name, prev_name) == 0)) {
 			gmenu_tree_item_unref (entry);
 			continue;
 		}
