@@ -535,6 +535,12 @@ eel_uri_is_trash (const char *uri)
 		|| eel_istr_has_prefix (uri, "gnome-trash:");
 }
 
+gboolean
+eel_uri_is_search (const char *uri)
+{
+	return eel_istr_has_prefix (uri, EEL_SEARCH_URI);
+}
+
 gboolean
 eel_uri_is_trash_folder (const char *uri)
 {
@@ -684,131 +690,6 @@ eel_format_uri_for_display_internal (const char *uri,
 	return canonical_uri;
 }
 
-static char *
-eel_escape_high_chars (const guchar *string)
-{
-	char *result;
-	const guchar *scanner;
-	guchar *result_scanner;
-	int escape_count;
-	static const gchar hex[16] = "0123456789ABCDEF";
-
-#define ACCEPTABLE(a) ((a)>=32 && (a)<128)
-	
-	escape_count = 0;
-
-	if (string == NULL) {
-		return NULL;
-	}
-
-	for (scanner = string; *scanner != '\0'; scanner++) {
-		if (!ACCEPTABLE(*scanner)) {
-			escape_count++;
-		}
-	}
-	
-	if (escape_count == 0) {
-		return g_strdup (string);
-	}
-
-	/* allocate two extra characters for every character that
-	 * needs escaping and space for a trailing zero
-	 */
-	result = g_malloc (scanner - string + escape_count * 2 + 1);
-	for (scanner = string, result_scanner = result; *scanner != '\0'; scanner++) {
-		if (!ACCEPTABLE(*scanner)) {
-			*result_scanner++ = '%';
-			*result_scanner++ = hex[*scanner >> 4];
-			*result_scanner++ = hex[*scanner & 15];
-			
-		} else {
-			*result_scanner++ = *scanner;
-		}
-	}
-
-	*result_scanner = '\0';
-
-	return result;
-}
-
-
-/* The strip_trailing_whitespace option is intended to make copy/paste of
- * URIs less error-prone when it is known that trailing whitespace isn't
- * part of the uri.
- */
-static char *
-eel_make_uri_from_input_internal (const char *text,
-				  gboolean filenames_are_utf8,
-				  const char *filename_charset,
-				  gboolean strip_trailing_whitespace)
-{
-	char *stripped, *path, *uri, *locale_path, *filesystem_path, *escaped;
-
-	g_return_val_if_fail (text != NULL, g_strdup (""));
-
-	/* Strip off leading whitespaces (since they can't be part of a valid
-	   uri).   Only strip off trailing whitespaces when requested since
-	   they might be part of a valid uri.
-	 */
-	if (strip_trailing_whitespace) {
-		stripped = g_strstrip (g_strdup (text));
-	} else {
-		stripped = g_strchug (g_strdup (text));
-	}
-
-	switch (stripped[0]) {
-	case '\0':
-		uri = g_strdup ("");
-		break;
-	case '/':
-		if (!filenames_are_utf8) {
-			locale_path = g_convert (stripped, -1, filename_charset, "UTF-8", NULL, NULL, NULL);
-			if (locale_path != NULL) {
-				uri = gnome_vfs_get_uri_from_local_path (locale_path);
-				g_free (locale_path);
-			} else {
-				/* We couldn't convert to the locale. */
-				/* FIXME: We should probably give a user-visible error here. */
-				uri = g_strdup("");
-			}
-		} else {
-			uri = gnome_vfs_get_uri_from_local_path (stripped);
-		}
-		break;
-	case '~':
-		if (!filenames_are_utf8) {
-			filesystem_path = g_convert (stripped, -1, filename_charset, "UTF-8", NULL, NULL, NULL);
-		} else {
-			filesystem_path = g_strdup (stripped);
-		}
-                /* deliberately falling into default case on fail */
-		if (filesystem_path != NULL) {
-			path = gnome_vfs_expand_initial_tilde (filesystem_path);
-			g_free (filesystem_path);
-			if (*path == '/') {
-				uri = gnome_vfs_get_uri_from_local_path (path);
-				g_free (path);
-				break;
-			}
-			g_free (path);
-		}
-                /* don't insert break here, read above comment */
-	default:
-		if (has_valid_scheme (stripped)) {
-			uri = eel_escape_high_chars (stripped);
-		} else {
-			escaped = eel_escape_high_chars (stripped);
-			uri = g_strconcat ("http://", escaped, NULL);
-			g_free (escaped);
-		}
-	}
-
-	g_free (stripped);
-
-	return uri;
-	
-}
-
 /**
  * eel_format_uri_for_display:
  *
@@ -860,110 +741,6 @@ has_valid_scheme (const char *uri)
 	return *p == ':';
 }
 
-/**
- * eel_make_uri_from_input:
- *
- * Takes a user input path/URI and makes a valid URI
- * out of it
- *
- * @location: a possibly mangled "uri", in UTF8
- *
- * returns a newly allocated uri.
- *
- * This function is the reverse of eel_format_uri_for_display
- * but it also handles the fact that the user could have typed
- * arbitrary UTF8 in the entry showing the string.
- *
- **/
-char *
-eel_make_uri_from_input (const char *location)
-{
-	gboolean utf8;
-	const char *charset;
-
-	utf8 = eel_get_filename_charset (&charset);
-
-	return eel_make_uri_from_input_internal (location, utf8, charset, TRUE);
-}
-
-char *
-eel_make_uri_from_input_with_trailing_ws (const char *location)
-{
-	gboolean utf8;
-	const char *charset;
-
-	utf8 = eel_get_filename_charset (&charset);
-
-	return eel_make_uri_from_input_internal (location, utf8, charset, FALSE);
-}
-
-/* Note that NULL's and full paths are also handled by this function.
- * A NULL location will return the current working directory
- */
-static char *
-file_uri_from_local_relative_path (const char *location)
-{
-	char *current_dir;
-	char *base_uri, *base_uri_slash;
-	char *location_escaped;
-	char *uri;
-
-	current_dir = g_get_current_dir ();
-	base_uri = gnome_vfs_get_uri_from_local_path (current_dir);
-	/* g_get_current_dir returns w/o trailing / */
-	base_uri_slash = g_strconcat (base_uri, "/", NULL);
-
-	location_escaped = gnome_vfs_escape_path_string (location);
-
-	uri = eel_uri_make_full_from_relative (base_uri_slash, location_escaped);
-
-	g_free (location_escaped);
-	g_free (base_uri_slash);
-	g_free (base_uri);
-	g_free (current_dir);
-
-	return uri;
-}
-
-/**
- * eel_make_uri_from_shell_arg:
- *
- * Similar to eel_make_uri_from_input, except that:
- * 
- * 1) guesses relative paths instead of http domains
- * 2) doesn't bother stripping leading/trailing white space
- * 3) doesn't bother with ~ expansion--that's done by the shell
- *
- * @location: a possibly mangled "uri"
- *
- * returns a newly allocated uri
- *
- **/
-char *
-eel_make_uri_from_shell_arg (const char *location)
-{
-	char *uri;
-
-	g_return_val_if_fail (location != NULL, g_strdup (""));
-
-	switch (location[0]) {
-	case '\0':
-		uri = g_strdup ("");
-		break;
-	case '/':
-		uri = gnome_vfs_get_uri_from_local_path (location);
-		break;
-	default:
-		if (has_valid_scheme (location)) {
-			uri = g_strdup (location);
-		} else {
-			uri = file_uri_from_local_relative_path (location);
-		}
-	}
-
-	return uri;
-}
-
 char *
 eel_uri_get_basename (const char *uri)
 {
@@ -983,270 +760,6 @@ eel_uri_get_basename (const char *uri)
 	return name;
 }
 
-char *
-eel_uri_get_scheme (const char *uri)
-{
-	char *colon;
-
-	g_return_val_if_fail (uri != NULL, NULL);
-
-	colon = strchr (uri, ':');
-	
-	if (colon == NULL) {
-		return NULL;
-	}
-	
-	return g_strndup (uri, colon - uri);
-}
-
-
-static gboolean
-is_uri_partial (const char *uri)
-{
-	const char *current;
-
-	/* RFC 2396 section 3.1 */
-	for (current = uri ; 
-		*current
-		&& 	((*current >= 'a' && *current <= 'z')
-			 || (*current >= 'A' && *current <= 'Z')
-			 || (*current >= '0' && *current <= '9')
-			 || ('-' == *current)
-			 || ('+' == *current)
-			 || ('.' == *current)) ;
-	     current++);
-
-	return  !(':' == *current);
-}
-
-/*
- * Remove "./" segments
- * Compact "../" segments inside the URI
- * Remove "." at the end of the URL 
- * Leave any ".."'s at the beginning of the URI
- */
-
-/*
- * FIXME this is not the simplest or most time-efficent way
- * to do this.  Probably a far more clear way of doing this processing
- * is to split the path into segments, rather than doing the processing
- * in place.
- */
-static void
-remove_internal_relative_components (char *uri_current)
-{
-	char *segment_prev, *segment_cur;
-	size_t len_prev, len_cur;
-
-	len_prev = len_cur = 0;
-	segment_prev = NULL;
-
-	g_return_if_fail (uri_current != NULL);
-
-	segment_cur = uri_current;
-
-	while (*segment_cur) {
-		len_cur = strcspn (segment_cur, "/");
-
-		if (len_cur == 1 && segment_cur[0] == '.') {
-			/* Remove "." 's */
-			if (segment_cur[1] == '\0') {
-				segment_cur[0] = '\0';
-				break;
-			} else {
-				memmove (segment_cur, segment_cur + 2, strlen (segment_cur + 2) + 1);
-				continue;
-			}
-		} else if (len_cur == 2 && segment_cur[0] == '.' && segment_cur[1] == '.' ) {
-			/* Remove ".."'s (and the component to the left of it) that aren't at the
-			 * beginning or to the right of other ..'s
-			 */
-			if (segment_prev) {
-				if (! (len_prev == 2
-				       && segment_prev[0] == '.'
-				       && segment_prev[1] == '.')) {
-				       	if (segment_cur[2] == '\0') {
-						segment_prev[0] = '\0';
-						break;
-				       	} else {
-						memmove (segment_prev, segment_cur + 3, strlen (segment_cur + 3) + 1);
-
-						segment_cur = segment_prev;
-						len_cur = len_prev;
-
-						/* now we find the previous segment_prev */
-						if (segment_prev == uri_current) {
-							segment_prev = NULL;
-						} else if (segment_prev - uri_current >= 2) {
-							segment_prev -= 2;
-							for ( ; segment_prev > uri_current && segment_prev[0] != '/' 
-							      ; segment_prev-- );
-							if (segment_prev[0] == '/') {
-								segment_prev++;
-							}
-						}
-						continue;
-					}
-				}
-			}
-		}
-
-		/*Forward to next segment */
-
-		if (segment_cur [len_cur] == '\0') {
-			break;
-		}
-		 
-		segment_prev = segment_cur;
-		len_prev = len_cur;
-		segment_cur += len_cur + 1;	
-	}	
-}
-
-
-/**
- * eel_uri_make_full_from_relative:
- * 
- * Returns a full URI given a full base URI, and a secondary URI which may
- * be relative.
- *
- * Return value: the URI (NULL for some bad errors).
- *
- * FIXME: This code has been copied from eel-mozilla-content-view
- * because eel-mozilla-content-view cannot link with libeel-extensions
- * due to lame license issues.  Really, this belongs in gnome-vfs, but was added
- * after the Gnome 1.4 gnome-vfs API freeze
- **/
-
-char *
-eel_uri_make_full_from_relative (const char *base_uri, const char *relative_uri)
-{
-	char *result = NULL;
-
-	/* See section 5.2 in RFC 2396 */
-
-	if (base_uri == NULL && relative_uri == NULL) {
-		result = NULL;
-	} else if (base_uri == NULL) {
-		result = g_strdup (relative_uri);
-	} else if (relative_uri == NULL) {
-		result = g_strdup (base_uri);
-	} else if (!is_uri_partial (relative_uri)) {
-		result = g_strdup (relative_uri);
-	} else {
-		char *mutable_base_uri;
-		char *mutable_uri;
-
-		char *uri_current;
-		size_t base_uri_length;
-		char *separator;
-
-		mutable_base_uri = g_strdup (base_uri);
-		uri_current = mutable_uri = g_strdup (relative_uri);
-
-		/* Chew off Fragment and Query from the base_url */
-
-		separator = strrchr (mutable_base_uri, '#'); 
-
-		if (separator) {
-			*separator = '\0';
-		}
-
-		separator = strrchr (mutable_base_uri, '?');
-
-		if (separator) {
-			*separator = '\0';
-		}
-
-		if ('/' == uri_current[0] && '/' == uri_current [1]) {
-			/* Relative URI's beginning with the authority
-			 * component inherit only the scheme from their parents
-			 */
-
-			separator = strchr (mutable_base_uri, ':');
-
-			if (separator) {
-				separator[1] = '\0';
-			}			  
-		} else if ('/' == uri_current[0]) {
-			/* Relative URI's beginning with '/' absolute-path based
-			 * at the root of the base uri
-			 */
-
-			separator = strchr (mutable_base_uri, ':');
-
-			/* g_assert (separator), really */
-			if (separator) {
-				/* If we start with //, skip past the authority section */
-				if ('/' == separator[1] && '/' == separator[2]) {
-					separator = strchr (separator + 3, '/');
-					if (separator) {
-						separator[0] = '\0';
-					}
-				} else {
-				/* If there's no //, just assume the scheme is the root */
-					separator[1] = '\0';
-				}
-			}
-		} else if ('#' != uri_current[0]) {
-			/* Handle the ".." convention for relative uri's */
-
-			/* If there's a trailing '/' on base_url, treat base_url
-			 * as a directory path.
-			 * Otherwise, treat it as a file path, and chop off the filename
-			 */
-
-			base_uri_length = strlen (mutable_base_uri);
-			if ('/' == mutable_base_uri[base_uri_length-1]) {
-				/* Trim off '/' for the operation below */
-				mutable_base_uri[base_uri_length-1] = 0;
-			} else {
-				separator = strrchr (mutable_base_uri, '/');
-				if (separator) {
-					*separator = '\0';
-				}
-			}
-
-			remove_internal_relative_components (uri_current);
-
-			/* handle the "../"'s at the beginning of the relative URI */
-			while (0 == strncmp ("../", uri_current, 3)) {
-				uri_current += 3;
-				separator = strrchr (mutable_base_uri, '/');
-				if (separator) {
-					*separator = '\0';
-				} else {
-					/* <shrug> */
-					break;
-				}
-			}
-
-			/* handle a ".." at the end */
-			if (uri_current[0] == '.' && uri_current[1] == '.' 
-			    && uri_current[2] == '\0') {
-
-			    	uri_current += 2;
-				separator = strrchr (mutable_base_uri, '/');
-				if (separator) {
-					*separator = '\0';
-				}
-			}
-
-			/* Re-append the '/' */
-			mutable_base_uri [strlen(mutable_base_uri)+1] = '\0';
-			mutable_base_uri [strlen(mutable_base_uri)] = '/';
-		}
-
-		result = g_strconcat (mutable_base_uri, uri_current, NULL);
-		g_free (mutable_base_uri); 
-		g_free (mutable_uri); 
-	}
-	
-	return result;
-}
-
-
-
 static gboolean
 eel_uri_is_local_scheme (const char *uri)
 {
@@ -1461,6 +974,9 @@ eel_make_uri_from_half_baked_uri (const char *half_baked_uri)
 	return eel_make_uri_canonical (half_baked_uri);
 }
 
+/* a copy of this function is in gnome-vfs-utils.c, used
+ * for gnome_vfs_uris_match, which doesn't ignore fragments
+ */
 static gboolean
 uris_match (const char *uri_1, const char *uri_2, gboolean ignore_fragments)
 {
@@ -1483,12 +999,6 @@ uris_match (const char *uri_1, const char *uri_2, gboolean ignore_fragments)
 	return result;
 }
 
-gboolean
-eel_uris_match (const char *uri_1, const char *uri_2)
-{
-	return uris_match (uri_1, uri_2, FALSE);
-}
-
 gboolean
 eel_uris_match_ignore_fragments (const char *uri_1, const char *uri_2)
 {
@@ -1678,60 +1188,6 @@ eel_filename_get_rename_region (const char           *filename,
 void
 eel_self_check_vfs_extensions (void)
 {
-	const char *charset;
-	
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (""), "");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (" "), "");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (" / "), "file:///");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (" /"), "file:///");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (" /home\n\n"), "file:///home");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (" \n\t"), "");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("!"), "http://!");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("#"), "http://#");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/ "), "file:///");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/!"), "file:///!");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/#"), "file:///%23");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/%20"), "file:///%2520");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/%25"), "file:///%2525");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/:"), "file:///%3A");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/home"), "file:///home");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("/home/darin"), "file:///home/darin");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (":"), "http://:");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("::"), "http://::");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input (":://:://:::::::::::::::::"), "http://:://:://:::::::::::::::::");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:"), "file:");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:///%20"), "file:///%20");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:///%3F"), "file:///%3F");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:///:"), "file:///:");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:///?"), "file:///?");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:///home/joe/some file"), "file:///home/joe/some file");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file://home/joe/some file"), "file://home/joe/some file");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("file:::::////"), "file:::::////");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("foo://foobar.txt"), "foo://foobar.txt");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("home"), "http://home");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("http://null.stanford.edu"), "http://null.stanford.edu");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("http://null.stanford.edu:80"), "http://null.stanford.edu:80");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("http://seth@null.stanford.edu:80"), "http://seth@null.stanford.edu:80");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("http:::::::::"), "http:::::::::");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("www.eazel.com"), "http://www.eazel.com");
-        EEL_CHECK_STRING_RESULT (eel_make_uri_from_input ("http://null.stanford.edu/some file"), "http://null.stanford.edu/some file");
-
-
-	/* not G_BROKEN_FILENAMES: */
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("/\346\227\245\346\234\254\350\252\236/\303\245\303\244\303\266", 1, "UTF-8", TRUE), "file:///%E6%97%A5%E6%9C%AC%E8%AA%9E/%C3%A5%C3%A4%C3%B6");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("http://www.google.com/\346\227\245\346\234\254\350\252\236/\303\245\303\244\303\266", 1, "UTF-8", TRUE), "http://www.google.com/%E6%97%A5%E6%9C%AC%E8%AA%9E/%C3%A5%C3%A4%C3%B6");
-
-	g_get_charset (&charset);
-	/* G_BROKEN_FILENAMES: */
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("/\303\245\303\244\303\266/test", 0, "ISO-8859-1", TRUE), "file:///%E5%E4%F6/test");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("/\346\227\245\346\234\254\350\252\236/test", 0, "ISO-8859-1", TRUE), "");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("/\346\227\245\346\234\254\350\252\236/test", 0, "EUC-JP", TRUE), "file:///%C6%FC%CB%DC%B8%EC/test");
-	EEL_CHECK_STRING_RESULT (eel_make_uri_from_input_internal ("/\303\245\303\244\303\266/test", 0, "EUC-JP", TRUE), "file:///%8F%AB%A9%8F%AB%A3%8F%AB%D3/test");
-
-	EEL_CHECK_STRING_RESULT (eel_uri_get_scheme ("file:///var/tmp"), "file");
-	EEL_CHECK_STRING_RESULT (eel_uri_get_scheme (""), NULL);
-	EEL_CHECK_STRING_RESULT (eel_uri_get_scheme ("file:///var/tmp::"), "file");
-	EEL_CHECK_STRING_RESULT (eel_uri_get_scheme ("man:ls"), "man");
 	EEL_CHECK_BOOLEAN_RESULT (eel_uri_is_local_scheme ("file:///var/tmp"), TRUE);
 	EEL_CHECK_BOOLEAN_RESULT (eel_uri_is_local_scheme ("http://www.yahoo.com"), FALSE);
 
@@ -1871,47 +1327,6 @@ eel_self_check_vfs_extensions (void)
 	EEL_CHECK_STRING_RESULT (eel_make_uri_from_half_baked_uri ("file:///%3F"), "file:///%3F");
 	EEL_CHECK_STRING_RESULT (eel_make_uri_from_half_baked_uri ("file:/%3F"), "file:///%253F");
 
-	EEL_CHECK_STRING_RESULT (eel_uri_make_full_from_relative (NULL, NULL), NULL);
-	EEL_CHECK_STRING_RESULT (eel_uri_make_full_from_relative ("http://a/b/c/d;p?q", NULL), "http://a/b/c/d;p?q");
-	EEL_CHECK_STRING_RESULT (eel_uri_make_full_from_relative (NULL, "http://a/b/c/d;p?q"), "http://a/b/c/d;p?q");
-
-	/* These test cases are from RFC 2396. */
-#define TEST_PARTIAL(partial, result) \
-	EEL_CHECK_STRING_RESULT (eel_uri_make_full_from_relative \
-		("http://a/b/c/d;p?q", partial), result)
-
-	TEST_PARTIAL ("g", "http://a/b/c/g");
-	TEST_PARTIAL ("./g", "http://a/b/c/g");
-	TEST_PARTIAL ("g/", "http://a/b/c/g/");
-	TEST_PARTIAL ("/g", "http://a/g");
-
-	TEST_PARTIAL ("//g", "http://g");
-	
-	TEST_PARTIAL ("?y", "http://a/b/c/?y");
-	TEST_PARTIAL ("g?y", "http://a/b/c/g?y");
-	TEST_PARTIAL ("#s", "http://a/b/c/d;p#s");
-	TEST_PARTIAL ("g#s", "http://a/b/c/g#s");
-	TEST_PARTIAL ("g?y#s", "http://a/b/c/g?y#s");
-	TEST_PARTIAL (";x", "http://a/b/c/;x");
-	TEST_PARTIAL ("g;x", "http://a/b/c/g;x");
-	TEST_PARTIAL ("g;x?y#s", "http://a/b/c/g;x?y#s");
-
-	TEST_PARTIAL (".", "http://a/b/c/");
-	TEST_PARTIAL ("./", "http://a/b/c/");
-
-	TEST_PARTIAL ("..", "http://a/b/");
-	TEST_PARTIAL ("../g", "http://a/b/g");
-	TEST_PARTIAL ("../..", "http://a/");
-	TEST_PARTIAL ("../../", "http://a/");
-	TEST_PARTIAL ("../../g", "http://a/g");
-
-	/* Others */
-	TEST_PARTIAL ("g/..", "http://a/b/c/");
-	TEST_PARTIAL ("g/../", "http://a/b/c/");
-	TEST_PARTIAL ("g/../g", "http://a/b/c/g");
-
-#undef TEST_PARTIAL
-
 	EEL_CHECK_STRING_RESULT (eel_format_uri_for_display (""), "/");
 	EEL_CHECK_STRING_RESULT (eel_format_uri_for_display (":"), ":///");
 	EEL_CHECK_STRING_RESULT (eel_format_uri_for_display ("file:///h/user"), "/h/user");
@@ -1933,13 +1348,6 @@ eel_self_check_vfs_extensions (void)
 	EEL_CHECK_STRING_RESULT (eel_format_uri_for_display_internal ("file:///%C6%FC%CB%DC%B8%EC/test", 0, "EUC-JP"), "/\346\227\245\346\234\254\350\252\236/test");
 	EEL_CHECK_STRING_RESULT (eel_format_uri_for_display_internal ("file:///%8F%AB%A9%8F%AB%A3%8F%AB%D3/test", 0, "EUC-JP"), "/\303\245\303\244\303\266/test");
 
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match ("", ""), TRUE);
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match (":", ":"), TRUE);
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match ("file:///h/user/file#gunzip:///", "file:///h/user/file#gunzip:///"), TRUE);
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match ("file:///h/user/file#gunzip:///", "file:///h/user/file#gzip:///"), FALSE);
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match ("http://www.Eazel.Com", "http://www.eazel.com"), TRUE);
-	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match ("http://www.Eazel.Com:80", "http://www.eazel.com:80"), TRUE);
-
 	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match_ignore_fragments ("", ""), TRUE);
 	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match_ignore_fragments (":", ":"), TRUE);
 	EEL_CHECK_BOOLEAN_RESULT (eel_uris_match_ignore_fragments ("file:///h/user/file#gunzip:///", "file:///h/user/file#gunzip:///"), TRUE);
